"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CoreApiClient = void 0;
const axios_1 = __importDefault(require("axios"));
const environments_1 = require("../configuration/environments");
const scopes_1 = require("../configuration/scopes");
const affiliationsClient_1 = require("./affiliationsClient");
const auth_1 = require("./auth");
const consentsClient_1 = require("./consentsClient");
const countriesClient_1 = require("./countriesClient");
const orgsClient_1 = require("./orgsClient");
const personsClient_1 = require("./personsClient");
const relationsClient_1 = require("./relationsClient");
const rolesClient_1 = require("./rolesClient");
const roleAssignmentsClient_1 = require("./roleAssignmentsClient");
class CoreApiClient {
    get affiliations() {
        return this._affiliations;
    }
    get consents() {
        return this._consents;
    }
    get countries() {
        return this._countries;
    }
    get orgs() {
        return this._orgs;
    }
    get persons() {
        return this._persons;
    }
    get relations() {
        return this._relations;
    }
    get roles() {
        return this._roles;
    }
    get roleAssignments() {
        return this._roleAssignments;
    }
    constructor(config) {
        var _a, _b, _c, _d, _e;
        const env = config.environment;
        this.auth = new auth_1.Auth({
            audience: (_a = config.customOauthAudience) !== null && _a !== void 0 ? _a : environments_1.defaultEnvironmentConfig[env].oauthAudience,
            clientId: config.clientId,
            clientSecret: config.clientSecret,
            scopes: (_b = config.scopes) !== null && _b !== void 0 ? _b : (env === environments_1.Environment.Emulator ? Object.values(scopes_1.Scope) : undefined),
            tokenUrl: (_c = config.customOauthTokenUrl) !== null && _c !== void 0 ? _c : environments_1.defaultEnvironmentConfig[env].tokenUrl,
            customOptions: (_d = config.customOptions) !== null && _d !== void 0 ? _d : (env === environments_1.Environment.Emulator ? { orgs: "-" } : undefined),
        });
        this.basePath =
            (_e = config.customApiBaseUrl) !== null && _e !== void 0 ? _e : environments_1.defaultEnvironmentConfig[env].apiBaseUrl;
        this._affiliations = new affiliationsClient_1.AffiliationsClient(this.basePath, this.auth);
        this._consents = new consentsClient_1.ConsentsClient(this.basePath, this.auth);
        this._countries = new countriesClient_1.CountriesClient(this.basePath, this.auth);
        this._orgs = new orgsClient_1.OrgsClient(this.basePath, this.auth);
        this._persons = new personsClient_1.PersonsClient(this.basePath, this.auth);
        this._relations = new relationsClient_1.RelationsClient(this.basePath, this.auth);
        this._roles = new rolesClient_1.RolesClient(this.basePath, this.auth);
        this._roleAssignments = new roleAssignmentsClient_1.RoleAssignmentsClient(this.basePath, this.auth);
    }
    refreshTestData() {
        return __awaiter(this, void 0, void 0, function* () {
            return axios_1.default.post(this.basePath + "/refresh-data");
        });
    }
}
exports.CoreApiClient = CoreApiClient;
