"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const helpers_1 = require("./helpers");
const auth_1 = require("../api/auth");
const sinon_1 = __importDefault(require("sinon"));
const environments_1 = require("../configuration/environments");
describe("Auth", () => __awaiter(void 0, void 0, void 0, function* () {
    const auth = new auth_1.Auth({
        audience: environments_1.defaultEnvironmentConfig[environments_1.Environment.Emulator].oauthAudience,
        clientId: "0000",
        clientSecret: "0000",
        tokenUrl: environments_1.defaultEnvironmentConfig[environments_1.Environment.Emulator].tokenUrl,
    });
    it("Authenticate token gets reused", () => __awaiter(void 0, void 0, void 0, function* () {
        const t1 = yield auth.getToken();
        yield (0, helpers_1.delay)(1000);
        const t2 = yield auth.getToken();
        chai_1.assert.equal(t1, t2);
    }));
    it("Authenticate expired token gets refreshed", () => __awaiter(void 0, void 0, void 0, function* () {
        const t1 = yield auth.getToken();
        yield (0, helpers_1.delay)(1000);
        const fakeClock = sinon_1.default.useFakeTimers(new Date());
        fakeClock.tick(2 * 24 * 60 * 60 * 1000);
        const t2 = yield auth.getToken();
        fakeClock.restore();
        chai_1.assert.notEqual(t1, t2);
    }));
}));
