"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const helpers_1 = require("./helpers");
const scopes_1 = require("../configuration/scopes");
const api_1 = require("../api");
describe("Countries", () => __awaiter(void 0, void 0, void 0, function* () {
    it("Countries find", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield helpers_1.client.countries.find();
        const country = result.data.find((c) => c.nameEn === "Netherlands");
        if (!country)
            throw Error("Country not defined");
        chai_1.assert.equal(country.uid, helpers_1.countryUid);
        chai_1.assert.equal(country.nameNative, "Nederland");
        chai_1.assert.equal(country.nameNo, "Nederland");
    }));
    it("Countries find with invalid scope", () => __awaiter(void 0, void 0, void 0, function* () {
        try {
            const config = (0, helpers_1.getDefaultConfig)();
            config.scopes = [scopes_1.Scope.PersonsRead];
            const clientWithOutScope = new api_1.CoreApiClient(config);
            yield clientWithOutScope.countries.find();
            chai_1.assert.fail("Was able to find with an invalid scope");
        }
        catch (err) {
            if (!(0, api_1.isCoreApiError)(err))
                throw Error("Invalid error type");
            chai_1.assert.equal(err.details.code, api_1.ErrorCode.MissingScopes);
        }
    }));
}));
