"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const helpers_1 = require("./helpers");
const api_1 = require("../api");
const error_1 = require("../model/error");
const scopes_1 = require("../configuration/scopes");
describe("Errors", () => __awaiter(void 0, void 0, void 0, function* () {
    it("Test error helpers", () => {
        function throwFunction() {
            throw new error_1.CoreApiError({
                error: {
                    code: api_1.ErrorCode.InvalidBody,
                    message: "test message",
                },
            });
        }
        try {
            throwFunction();
        }
        catch (err) {
            if (!(0, api_1.isCoreApiError)(err))
                throw "Invalid error type";
            chai_1.assert.equal(err.details.code, api_1.ErrorCode.InvalidBody);
            chai_1.assert.equal(err.message, "test message");
        }
    });
    it("Invalid scope error", () => __awaiter(void 0, void 0, void 0, function* () {
        try {
            const config = (0, helpers_1.getDefaultConfig)();
            config.scopes = [scopes_1.Scope.PersonsRead];
            const clientWithOutScope = new api_1.CoreApiClient(config);
            yield clientWithOutScope.affiliations.get(helpers_1.affiliationUid);
            chai_1.assert.fail("Was able to remove with an invalid scope");
        }
        catch (err) {
            if (!(err instanceof error_1.CoreApiError))
                chai_1.assert.fail("Invalid error type");
            chai_1.assert.equal(err.details.code, api_1.ErrorCode.MissingScopes);
            chai_1.assert.equal(err.message, "not allowed: missing scope: need any of persons.affiliations#read");
        }
    }));
    it("Non existing error", () => __awaiter(void 0, void 0, void 0, function* () {
        try {
            const fakeUid = "657a66ca-9cd0-4b61-9476-697016e26fbc";
            yield helpers_1.client.affiliations.get(fakeUid);
            chai_1.assert.fail("Was able to remove with a non existing affiliation");
        }
        catch (err) {
            if (!(err instanceof error_1.CoreApiError))
                chai_1.assert.fail("Invalid error type");
            chai_1.assert.equal(err.details.code, api_1.ErrorCode.NotFound);
        }
    }));
}));
