var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { client } from "./helpers";
import { Affiliation, WrappedWithMetaArrayPerson } from "../api";
import { assert } from "chai";
describe("Querying", () => __awaiter(void 0, void 0, void 0, function* () {
    let allPersons;
    before(() => __awaiter(void 0, void 0, void 0, function* () {
        allPersons = (yield client.persons.find()).data;
    }));
    beforeEach(() => __awaiter(void 0, void 0, void 0, function* () {
        yield client.refreshTestData();
    }));
    it("sorting", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.persons.find({
            sort: [{
                    direction: 'ascending',
                    path: "displayName",
                }],
            limit: 2,
            offset: 1
        });
        assert.equal(result.meta.total, allPersons.length);
        assert.equal(result.meta.skipped, 1);
        assert.equal(result.meta.limit, 2);
        assert.instanceOf(result, WrappedWithMetaArrayPerson);
        const sortedPersons = allPersons.sort((a, b) => a.displayName > b.displayName ? 1 : -1);
        assert.equal(result.data[0].uid, sortedPersons[1].uid);
        assert.equal(result.data[1].uid, sortedPersons[2].uid);
    }));
    it("filtering", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.persons.find({
            filter: {
                displayName: {
                    _gte: "Philly Daly"
                }
            }
        });
        const expectedResult = allPersons.filter(p => p.displayName >= "Philly Daly");
        assert.equal(result.meta.total, expectedResult.length);
    }));
    it("filtering nested", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.persons.find({
            filter: {
                affiliations: {
                    person: {
                        displayName: {
                            _eq: "Philly Daly"
                        }
                    }
                }
            }
        });
        const expectedResult = allPersons.filter(p => p.displayName >= "Philly Daly");
        assert.equal(result.meta.total, expectedResult.length);
    }));
    it("resolving", () => __awaiter(void 0, void 0, void 0, function* () {
        var _a;
        const result = yield client.persons.find({
            fields: ["*", "affiliations.*"]
        });
        assert.instanceOf((_a = result.data[0].affiliations) === null || _a === void 0 ? void 0 : _a[0], Affiliation);
    }));
}));
